#!/bin/bash

. /etc/init.d/functions.sh

#GIT_URL="git://git.kernel.org/pub/scm/linux/storage/autofs/autofs.git"
GIT_URL="/root/autofs"
PATCHDIR="tmp/patches"
INFODIR="${PATCHDIR}/info"
GIT="$(which git)"

VER="$1"
PVER="$2"

ARCHIVE="autofs-${VER}-patches-${PVER}.tar.lzma"
OMITFILE=${3:-"autofs-${VER}.omit"}

if [[ $# -lt 2 ]]; then
	einfo "Usage: $0 <pkg ver> <patch ver> [omitted file]"
	exit 1
fi

if [[ -z ${GIT} ]]; then
	eerror "git not found!"
	exit 1
fi

if [[ -e ${ARCHIVE} ]]; then
	eerror "Archive '${ARCHIVE}' does already exist! Abort."
	exit 1
fi

rm -rf tmp
rm -f ${ARCHIVE}

mkdir -p ${INFODIR}

pushd ${PATCHDIR} >/dev/null || exit 1
${GIT} clone ${GIT_URL} || exit 1

pushd autofs >/dev/null || exit 1
${GIT} format-patch release_${1//./_} -o ../. || exit 1
popd >/dev/null|| exit 1

for PATCH in *.patch; do
	SUFFIX=""
	if [[ -f ${OMITFILE} ]] && $(grep -q ${PATCH} ${OMITFILE}); then
		ewarn "patch omitted: ${PATCH}"
		SUFFIX=".omitted"
	fi
	mv ${PATCH} ${PATCH/-autofs-[0-9].[0-9].[0-9]-/_all_}${SUFFIX} || exit 1
done
rm -rf autofs || exit 1
popd >/dev/null || exit 1

if [[ -e ../README.Gentoo.patches ]]; then
	cp ../README.Gentoo.patches ${INFODIR}/ || exit 1
else
	if [[ -e README.Gentoo.patches ]]; then
		cp README.Gentoo.patches ${INFODIR}/ || exit 1
	fi
fi

if [[ -f ${OMITFILE} ]]; then
	cp ${OMITFILE} ${INFODIR}/ || exit 1
fi

cat >${INFODIR}/README <<-EOF
	Patchset generated on $(date).

	This patchset was automatically generated using upstream's git tree
	located at ${GIT_URL}.
	Refer to ${OMITFILE} if patches are marked to be omitted.
EOF

cp $0 ${INFODIR}/ || exit 1

tar -c --lzma -f ${ARCHIVE} -C tmp . || exit 1
rm -rf tmp

einfo "Patchset generation run successfully :)"
einfo "File size of ${ARCHIVE}: $(du -bh ${ARCHIVE} | cut -f1)"
